18.10.0 (2018-10-09) — Lino Tera Benutzerhandbuch

# 18.10.0 (2018-10-09)

Allgemein:

- Vera übernimmt die Buchhaltung : Alle Einkaufsrechnungen und Kontoauszüge werden schon in Lino erfasst. Verkaufsrechnungen werden in 2018 noch mit den beiden TIMs erstellt und ausgedruckt, aber daraufhin die jeweiligen Beträge manuell in Lino erfasst, evtl. in einem eigenen Journal (ähnlich wie OD), pro Serie von Rechnungen wird dort ein einziges Dokument erstellt.

- Auch die DLS und DLP aus TIM (Termine und Anwesenheiten) werden jetzt nach Lino importiert. Ich kann auf Knopfdruck über Nacht neue Versionen aufspielen und alle Daten aus TIM nach Lino importieren. Wir haben uns mündlich auf ein Entwicklerpasswort geeinigt, mit dem DD, LS, GV und HS sich während der Testphase einloggen können. Alle anderen Benutzer wurden zwar erstellt, aber können sich nicht anmelden.

DONE:

- dashboard aktivieren

- Überfällige Termine : nicht schon die von heute, erst ab gestern.

- users.UserDetail hat keine Reiter (Dashboard, event_type, …)

- Terminzustand „Unentschuldigt ausgefallen“ fehlt

- Wenn DLP->Status leer ist, dann soll in Lino Anwesend stehen.

- Anwesenheiten der Teilnehmer werden nur in therapeutischen Gruppen erfasst, bei Einzeltherapien und Lebensgruppen gelten immer alle als anwesend (werden ansonsten gelöscht). Wenn so ein Termin auf „Stattgefunden“ gesetzt wird, werden alle Gäste ungefragt auf „Anwesend“ gesetzt. Wenn Termin auf Verpasst gesetzt wird, werden alle auf Unentschuldigt gesetzt. Lino hat ein Mapping von EntryStates nach GuestStates. (Details sh. Spezifikationen).

TODO:

- Preisliste : - course_line - entry_type - client_tariff - price - new_price?

- „Arbeiten als“ zeigt auch den aktuellen User an.

- Übersetzung „Life groups“

- Professional situation : Liste übersetzen. „Homemaker“ ersetzen durch „Housewife“?

- Lebensgruppen haben keine Teilnehmer?

- Problem Import Akte Melinda : Mitglieder in Familie sind doppelt. Es gibt nur eine Familientherapie, keine Einzeltherapie.

- DLS->IdUser wird scheinbar nicht importiert. Therapeut ist nicht immer der aus der Akte.

TALK

- Gekoppelte Termine KITZ : wie regeln wir das?

- Termine mit zwei Therapeuten: einer der beiden ist nur „Assistent“ und wird als Teilnehmer mit Rolle „Assistent“ erfasst.

- Abrechnung an Krankenkassen

- Klären, wie die Securex-Rechnungen verbucht werden sollen.

- Die Kalenderfunktionen soll so gut werden, dass OpenExchange nicht mehr nötig ist.

- Fakturierung testen: in Lino Rechnungen machen lassen und schauen, ob sie mit der Wirklichkeit übereinstimmen.

- „endet um“ kann bis auf weiteres leer sein

- Abonnements (eine Rechnung für alle Termine einer Therapie)

- Tagesplaner

- Terminplanung : Wochen-Master (Stundenplan), Monatsplaner (Wo sind Lücken? Ausnahmen regeln), Wochenansicht mit diversen Filtermöglichkeiten, Terminblätter drucken zum Verteilen. Zugewiesene Termine werden nicht angezeigt im Dashboard.

- Themen sind pro Familie und pro Klient, Notizen nur pro Klient.

- MTI Navigator can be irritating. Possibility to hide certain links & conversions. e.g. Person -> Houshold, Person -> Partner should be hidden for normal users.